@@ -6,13 +6,13 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocomplete', 'io.ox/mail/util', 'io.ox/contacts/util',
-                              'io.ox/core/tk/dialogs', 'io.ox/core/notifications', 'gettext!oxguard/file/share'],
-        function (ext, AutocompleteAPI, mailUtil, contactsUtil, dialogs, notifications, gt) {
+define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/tk/autocomplete', 'io.ox/core/api/autocomplete', 'io.ox/mail/util', 'io.ox/contacts/util', 'oxguard/core/og_http',
+                              'io.ox/core/tk/dialogs', 'io.ox/core/notifications', 'io.ox/mail/write/view-main', 'gettext!oxguard/file/share', 'less!io.ox/mail/write/style'],
+        function (ext, autocomplete, AutocompleteAPI, mailUtil, contactsUtil, og_http, dialogs, notifications, compview, gt) {
     'use strict';
     
-    var autocompleteAPI = new AutocompleteAPI({ id: 'mailwrite', contacts: true, msisdn: true });
-
+    var autocompleteAPI = new AutocompleteAPI({ users:true, contacts: true, groups : true });
+    
     // Create autocomplete field for sharing input
     function createShareInput(fileid) {
         var node = this;
@@ -20,6 +20,7 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
         .click(function () {
             $('#share_field_share').trigger($.Event('keydown', {which: 13}));
         });
+        try {
         return $('<div class="fieldset fs_fieldset">').append(
                 $('<label>' + gt('Add:') + ' </label>', { 'for' : 'share_field_share'})
                 .addClass('wrapping-label')
@@ -32,6 +33,7 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
                     })
                     .autocomplete({
                         api: autocompleteAPI,
+                        autoselect: true,
                         reduce: function (data) {
                             var hash = {},
                                 list;
@@ -61,7 +63,6 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
                                     display_name : e.data.display_name,
                                     email : e.data.email
                                 };
-                            console.log(fileid);
                             if (window.oxguarddata.passcode === null) {
                                 getPassword(data, node, fileid, true);
                             } else {
@@ -95,6 +96,10 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
                     })
                 )
             ).append(addButton);
+        } catch (e) {
+            console.log(e);
+            return(null);
+        }
     }
     
     // Share is not one from address book or contacts, assume an email
@@ -162,7 +167,8 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
 
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&id=' + id;
         $('.og_sharetable').html('<tr><td><i class="fa fa-spinner fa-spin" id="busygif"></td></tr>');
-        $.get(ox.apiRoot + '/oxguard/file?action=getshare' + params, function (data) {//Get the key
+        og_http.get(ox.apiRoot + '/oxguard/file?action=getshare', params)
+        .done(function (data) {//Get the key
             var users = JSON.parse(data);
             var table = $('<table class="og_sharetable"/>');
             if (users.length > 0) {
@@ -261,7 +267,8 @@ define('oxguard/file/share', ['io.ox/core/extensions', 'io.ox/core/api/autocompl
             return;
         }
         var params = '&id=' + baton.data.folder_id + '&session=' + ox.session;
-        $.get(ox.apiRoot + '/oxguard/file?action=getfolder' + params, function (data) {//Get the key
+        og_http.get(ox.apiRoot + '/oxguard/file?action=getfolder', params)
+        .done(function (data) {//Get the key
             var folderdata = JSON.parse(data);
             var permissions = folderdata.data.permissions;
             var notfound = checkpermissions(tolist, permissions);
