@@ -7,24 +7,23 @@
  *
  * Copyright (C) Open-Xchange Inc., 2006-2011
  */
-define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core', 'io.ox/core/notifications',
+define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core',
                            'gettext!oxguard/register', 'css!oxguard/style.css'],
-                           function (ext, oxguard, notify, gt) {
+                           function (ext, oxguard, gt) {
     'use strict';
     
     
     var oxguarddata = {
             passcode : null,
             settings:  {},
-            version: '1.0.0-0'
+
+            version: '1.2.0-4'
+
         };
     window.oxguarddata = oxguarddata;
     
     // Login section
-    if (sessionStorage !== null) {// If we were passed login info from login screen
-        sendauth(sessionStorage.oxguard === undefined ? '' : sessionStorage.oxguard);
-        sessionStorage.oxguard = null;// null out the sessionStorage
-    } else sendauth('');
+    sendauth('');
     
    
     function sendauth(pass)
@@ -46,7 +45,9 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core', 'io
             if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
             oxguarddata.settings = data.settings; // user settings
             oxguarddata.lang = data.lang;// Languages available
+            oxguarddata.server = data.server;
             oxguarddata.baton = window.oxguarddata.baton;
+            oxguarddata.pubkey = data.pubKey;
             window.oxguarddata = oxguarddata;
             if (window.oxguarddata.baton !== undefined) {
                 require(['oxguard/register_mail'], function (mail) {
@@ -54,6 +55,18 @@ define('oxguard/register', ['io.ox/core/extensions', 'oxguard/oxguard_core', 'io
                 });
                 window.oxguarddata.baton = undefined;
             }
+            if (sessionStorage !== null) {// If we were passed login info from login screen
+                try {
+                    if (sessionStorage.oxguard && (sessionStorage.oxguard !== 'null')) {
+                        var p = sessionStorage.oxguard;
+                        sessionStorage.oxguard = null;
+                        sendauth(p);
+                    }
+                } catch (e) {
+                    console.log('Private mode');
+                    return;
+                }
+            }
         })
         .fail(function () {
             $('.og_signout').hide();
