@@ -1,9 +1,29 @@
 define('oxguard/settings/pane',
-    ['io.ox/core/extensions', 'io.ox/core/tk/dialogs', 'oxguard/crypto/encr',
-       'gettext!oxguard/settings/pane'], function (ext, dialogs, encr, gt) {
+    ['io.ox/core/extensions', 'io.ox/core/tk/dialogs', 'oxguard/crypto/encr', 'oxguard/core/og_http',
+       'gettext!oxguard/settings/pane'], function (ext, dialogs, encr, og_http, gt) {
     'use strict';
 
     
+    function setupGuard (where) {
+        var passheader =
+            $('<div class="oxguard_settings"/>')
+            .append('<legend class="sectiontitle">' + gt('Get Started') + '</legend></br>');
+        var instructions = $('<div>');
+        instructions.append('<p>' + gt('In order to start with Guard Security, you must set up a password for your secured files.') + '</p>');
+        var startButton = $('<button type="button" class="btn btn-primary">' + gt('Start') + '</button>');
+        startButton.click (function () {
+            require(['oxguard/oxguard_core'], function (oxguard) {
+                oxguard.createKeys()
+                .done(function () {
+                    where.replaceWith(addSettings());
+                });
+            });
+        });
+        var holder = $('<div>').css('max-width', '800px');
+        holder.append('<h1>' + gt('Guard Security Settings') + '</h1><br/>');
+        where.append(holder.append(passheader.append(instructions).append(startButton)));
+    }
+    
     function createPasswordChange() {
         var passheader =
         $('<div class="oxguard_settings"/>')
@@ -53,10 +73,12 @@ define('oxguard/settings/pane',
     }
     
     function updateEmail () {
-        $.get(ox.apiRoot + '/oxguard/login?action=secondary&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id, function (d) {
+        og_http.get(ox.apiRoot + '/oxguard/login?action=secondary', '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id)
+        .done(function (d) {
             d = d.trim();
             if (d.length < 2) {
-                $('#currentsecondary').html(gt('None'));
+                //#. No recovery email was given, so we will use the primary email address when resetting
+                $('#currentsecondary').html(gt('None - Primary Email will be used'));
             } else {
                 $('#currentsecondary').html(d);
             }
@@ -93,6 +115,49 @@ define('oxguard/settings/pane',
         }
     }
     
+    function defaultGuard() {
+        var defaultHeader =
+            $('<div class="oxguard_settings"/>')
+            .append('<legend class="sectiontitle">' + gt('Defaults') + '</legend></br>');
+            var defaultbox = $('<input type="checkbox" name="defaultguard" style="margin-right:15px; margin-top:1px;"/> ');
+            defaultbox.on('click', function() {
+                if (window.oxguarddata.settings === null) {
+                    require(['io.ox/core/notifications'], function (notify) {
+                        notify.yell('error', gt('Not able to contact guard server'));
+                    });
+                    return;
+                }
+                sendDefaults();
+                
+            });
+            defaultHeader.append(defaultbox).append(gt('Use Guard when composing a new email'));
+            if (window.oxguarddata.settings.defaultGuard !== undefined) {
+                defaultbox.prop('checked', window.oxguarddata.settings.defaultGuard);
+            }
+            return(defaultHeader);
+    }
+    
+    function sendDefaults() {
+        var defaultChecked = $('input[name="defaultguard"]').is(':checked');
+        window.oxguarddata.settings.defaultGuard = defaultChecked;
+        var data = {
+                defaultGuard : defaultChecked
+        };
+        var json = {
+                id : ox.user_id,
+                cid : ox.context_id,
+                data : data
+        };
+        $.post(ox.apiRoot + '/oxguard/settings?action=set&session=' + ox.session, JSON.stringify(json), function () {
+
+        })
+        .fail (function () {
+            require(['io.ox/core/notifications'], function (notify) {
+                notify.yell('error', gt('Failed to update settings'));
+            });
+        });
+    }
+    
     function showError(id) {
         $('#' + id).show();
         window.setTimeout(function () {
@@ -115,7 +180,8 @@ define('oxguard/settings/pane',
                 waitdiv.show();
                 var param = '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id +
                 '&default=' + encodeURIComponent(primaryEmail) + '&lang=' + ox.language;
-                $.get(ox.apiRoot + '/oxguard/login?action=reset' + param, function (data) {
+                og_http.get(ox.apiRoot + '/oxguard/login?action=reset', param)
+                .done(function (data) {
                     $('.og_wait').remove();
                     require(['io.ox/core/notifications'], function (notify) {
                         if (data.indexOf('primary') >= 0) {
@@ -252,7 +318,7 @@ define('oxguard/settings/pane',
                 var data = event.target.result;
                 var privkey = encr.decodeKey(data, $('#priv_pass').val());
                 if (privkey === null) {
-                    alert(gt('Unable to open/decode private key'));
+                    alert(gt('Unable to open/decrypt private key'));
                 } else {
                     require(['oxguard/crypto/jsencrypt'], function (JS) {
                         var encrypt = new JS.JSEncrypt();
@@ -377,17 +443,21 @@ define('oxguard/settings/pane',
         id: 'oxguardsettings',
         draw: function () {
             if (window.oxguarddata.passcode === 'No Key') {
-                require(['oxguard/oxguard_core'], function (oxguard) {
-                    oxguard.createKeys();
-                });
+                this.append(setupGuard(this));
+                return;
             }
-            var holder = $('<div>').css('max-width', '800px');
-            holder.append('<h1>' + gt('Guard Security Settings') + '</h1><br/>');
+            
           //  this.append(holder.append(createPasswordChange())).append(createKeyManager());
-            this.append(holder.append(createPasswordChange()).append(createPasswordReset()).append(createSecondaryChange()));
+            this.append(addSettings());
         },
 
         save: function () {
         }
     });
+    
+    function addSettings () {
+        var holder = $('<div>').css('max-width', '800px');
+        holder.append('<h1>' + gt('Guard Security Settings') + '</h1><br/>');
+        return (holder.append(defaultGuard()).append(createPasswordChange()).append(createPasswordReset()).append(createSecondaryChange()));
+    }
 });
